@@ -1,5 +1,5 @@
 use DBIx::Squirrel database_entities => [qw/db get_artists/];
-use DBIx::Squirrel::Iterator qw/database result result_offset/;
+use DBIx::Squirrel::it qw/database result result_offset/;
 
 db do {
     DBIx::Squirrel->connect(
@@ -15,15 +15,21 @@ db do {
 
 get_artists do {
     db->results(
-        "SELECT ArtistId, Name FROM artists LIMIT 100" => sub {
+        [
+            'SELECT ArtistId, Name',
+            'FROM artists',
+            'LIMIT 10',
+        ] => sub {
             my($artist) = @_;
             printf "---- %s\n", database;
             printf "%4d Name: %s\n", result_offset, $artist->Name;
             return $artist;
-        } => sub {$_->ArtistId}
+        } => sub {
+            $_->ArtistId;
+        },
     );
 };
 
-get_artists->all;
+get_artists->all();
 
 db->disconnect();
