@@ -1,5 +1,5 @@
 package    # hide from PAUSE
-  DBIx::Squirrel::Transform::YAML::Syck;
+    DBIx::Squirrel::Transform::YAML::Syck;
 
 use strict;
 use warnings;
@@ -11,7 +11,8 @@ BEGIN {
     $DBIx::Squirrel::Transform::YAML::Syck::VERSION   = $DBIx::Squirrel::VERSION;
     @DBIx::Squirrel::Transform::YAML::Syck::ISA       = qw/Exporter/;
     @DBIx::Squirrel::Transform::YAML::Syck::EXPORT_OK = qw/as_yaml/;
-    @DBIx::Squirrel::Transform::YAML::Syck::EXPORT    = @DBIx::Squirrel::Transform::YAML::Syck::EXPORT_OK;
+    @DBIx::Squirrel::Transform::YAML::Syck::EXPORT
+        = @DBIx::Squirrel::Transform::YAML::Syck::EXPORT_OK;
 }
 
 sub as_yaml {
