@@ -33,7 +33,8 @@ use Sub::Name 'subname';
 use namespace::clean;
 
 BEGIN {
-    require DBIx::Squirrel unless keys(%DBIx::Squirrel::);
+    require DBIx::Squirrel
+        unless keys %DBIx::Squirrel::;
     *DBIx::Squirrel::rs::VERSION = *DBIx::Squirrel::VERSION;
     @DBIx::Squirrel::rs::ISA     = 'DBIx::Squirrel::it';
 }
